@@ -197,16 +197,16 @@ def _insert_jos_xgroups(db, name, description='', grouptype=0, gidNumber=0):
 
 	if not gidNumber:
 		sql =  "INSERT INTO jos_xgroups ( `cn`, `description`, `published`, `type`, `public_desc`, `private_desc`, `restrict_msg`, "
-		sql += "`join_policy`, `discussion_email_autosubscribe`, `logo`, `overview_type`, `overview_content`, `plugins`, `created`,"
+		sql += "`join_policy`, `discussion_email_autosubscribe`, `logo`,  `plugins`, `created`,"
 		sql += "`created_by`, `params`) " 
-		sql += "VALUES (" + '%s,'*15 + "%s );" 
-		data = (name, description, 0, int(grouptype), '', '', '', 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
+		sql += "VALUES (" + '%s,'*13 + "%s );" 
+		data = (name, description, 0, int(grouptype), '', '', '', 1, 0, '', None, datetime.datetime.now(), None, None)
 	else:
 		sql =  "INSERT INTO jos_xgroups ( `gidNumber`, `cn`, `description`, `published`, `type`, `public_desc`, `private_desc`, `restrict_msg`, "
-		sql += "`join_policy`, `discussion_email_autosubscribe`, `logo`, `overview_type`, `overview_content`, `plugins`, `created`,"
+		sql += "`join_policy`, `discussion_email_autosubscribe`, `logo`, `plugins`, `created`,"
 		sql += "`created_by`, `params`) " 
-		sql += "VALUES (" + '%s,'*16 + "%s );" 
-		data = (gidNumber, name, description, 0, int(grouptype), '', '', '', 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
+		sql += "VALUES (" + '%s,'*14 + "%s );" 
+		data = (gidNumber, name, description, 0, int(grouptype), '', '', '', 1, 0, '', None, datetime.datetime.now(), None, None)
 
 	gidNumber = db.query_lastrowid(sql, data)
 
